#if !defined(AFX_PASSPHRASEDLG_H__628EDA40_B337_11D5_B88F_00402676496C__INCLUDED_)
#define AFX_PASSPHRASEDLG_H__628EDA40_B337_11D5_B88F_00402676496C__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// PassPhraseDlg.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CPassPhraseDlg _CAO

class CPassPhraseDlg : public CDialog
{
// RXgNV
public:
	CString GetPass();
	CPassPhraseDlg(CWnd* pParent = NULL);   // W̃RXgN^

// _CAO f[^
	//{{AFX_DATA(CPassPhraseDlg)
	enum { IDD = IDD_PASSWORD };
	CEdit	m_ec;
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CPassPhraseDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CPassPhraseDlg)
	virtual BOOL OnInitDialog();
	virtual void OnOK();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
//	int m_flag;
	CString m_pass;
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_PASSPHRASEDLG_H__628EDA40_B337_11D5_B88F_00402676496C__INCLUDED_)
